version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 2

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// first block: robustness to specification
// baseline from table 1 main
reghdfe  dchildren lfine l.children, absorb(i.simpleID i.ageyeargroups) cluster(segroup)
gen basesample = e(sample)
matrix  b1_m1  = e(b)[1,1]
matrix se1_m1  = sqrt(e(V)[1,1])
matrix  b2_m1  = e(b)[1,2]
matrix se2_m1  = sqrt(e(V)[2,2])
xtdes if e(sample) == 1
matrix   N_m1    = r(N)
matrix   T_m1    = r(mean)

// ultrasound
// merge ultrasound data
rename    province_code province 
merge m:1 province using data_alz_jpe_ultracapitalcollapse
drop if _merge == 2
drop _merge

// interact fines with ultrasound 
gen     ultraind = 0 if ultra_capital !=. & year !=.
replace ultraind = 1 if year > ultra_cap & ultra_cap !=. & year !=.
foreach var of varlist fine finealt_exp {
	gen ultra`var' = ultraind*`var'
}

// system gmm
// residualize variables from province times year times age
foreach var of varlist fine ultrafine finealt_exp ultrafinealt_exp lchildren lm_children lf_children {
	xtset simpleID age
	reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
foreach var of varlist m_children f_children children inducedabortions abortions {
	reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}

// convert prices into 2020 dollars
foreach var of varlist lffine lffinealt_exp {
	replace `var' = exp(`var')*4.5*1.19*326.027
}

xtset simpleID age
// induced abortions
global group_1 if basesample == 1 & firstchildgirl == 1 & lchildren >= 1 & lchildren <= 1
global group_2 if basesample == 1 & firstchildgirl == 1 & lchildren >= 1 & lchildren <= 2
global group_3 if basesample == 1 & firstchildgirl == 1 & lchildren >= 1 & lchildren <= .
global group_4 if basesample == 1 & firstchildgirl == 1 & lchildren >= 2 & lchildren <= .

global group_5 if basesample == 1 & firstchildgirl == 0 & lchildren >= 1 & lchildren <= 1
global group_6 if basesample == 1 & firstchildgirl == 0 & lchildren >= 1 & lchildren <= 2
global group_7 if basesample == 1 & firstchildgirl == 0 & lchildren >= 1 & lchildren <= .
global group_8 if basesample == 1 & firstchildgirl == 0 & lchildren >= 2 & lchildren <= .
	
xtset simpleID age
foreach num of numlist 1(1)8 {
	# delimit
	xtdpd L(0/1).inducedabortions_resid L(0).(fine_resid lm_children_resid lf_children_resid) ${group_`num'}, 
							dgmmiv(inducedabortions_resid) dgmmiv(L2.(fine_resid lm_children_resid lf_children_resid), lag(1 .)) 
							lgmmiv(inducedabortions_resid L1.(fine_resid lm_children_resid lf_children_resid)) nocons twostep 
							vce(robust) iv(finealt_exp_resid);
	# delimit cr
	matrix   b1_m`num'  = e(b)[1,2]
	matrix  se1_m`num'  = sqrt(e(V)[2,2])
	summ   dinducedabortions if e(sample) == 1
	matrix mean = r(mean)
	nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
	matrix  b2_m`num'  = (r(b)[1,1])
	matrix  se2_m`num'  = sqrt(r(V)[1,1])
	summ lffine if e(sample) == 1
	matrix  price_m`num' = r(mean)
	xtdes if e(sample) == 1
	matrix   N_m`num'    = r(N)
	matrix   T_m`num'    = r(mean) 

	matrix m`num' = [b1_m`num',se1_m`num',b2_m`num',se2_m`num',price_m`num',N_m`num',T_m`num']'
}

matrix place3 = J(3,8,.)
matrix all = [place3 \ [m1,m2,m3,m4,m5,m6,m7,m8]] 
clear
svmat all
gen n = _n
foreach var of varlist all* {
	format  `var' %15.3fc
	replace `var' = round(`var',.001) 
	gen    `var'and = "&" if n !=1
}

gen all0and = "&" if n != 1
gen     all1_0 = "\begin{tabular}{ L{2cm} C{3cm} C{3cm} C{3cm} C{3cm} C{3cm} C{3cm} C{3cm} C{3cm}} \toprule" if n == 1

replace all1_0  = "& \multicolumn{4}{c}{\textbf{\textit{Panel a.} First-Child Girl}} & \multicolumn{4}{c}{\textbf{\textit{Panel b.} First-Child Boy}}"  									if n == 2
replace all1_0  = "& \textit{Stock: $1$} & \textit{Stock: $1-2$} & \textit{Stock: $\geq 1$} & \textit{Stock: $\geq 2$} & \textit{Stock: $1$} & \textit{Stock: $1-2$} & \textit{Stock: $\geq 1$} & \textit{Stock: $\geq 2$} "  if n == 3     

replace all0and = "   "       																			  if n == 2 | n == 3  
replace all1and = "   "           						      							  				  if n == 2 | n == 3  
replace all2and = "   "           						      							  				  if n == 2 | n == 3  
replace all3and = "   "       															  				  if n == 2 | n == 3  
replace all4and = "   "           						      							  				  if n == 2 | n == 3  
replace all5and = "   "           						      							  				  if n == 2 | n == 3  
replace all6and = "   "           						      							  				  if n == 2 | n == 3 
replace all7and = "   "           						      							  				  if n == 2 | n == 3  
replace all8and = "   "           						      							  				  if n == 2 | n == 3  

replace all1_0 =  "\multicolumn{1}{l}{Semi-Elastcity: $ \hat{\gamma}_{\Xi} $}" if n == 4  
replace all1_0 = "\multicolumn{1}{l}{(s.e.)}"                                  if n == 5  

replace all1_0 = "\multicolumn{1}{l}{Elasticity}"                              if n == 6  
replace all1_0 = "\multicolumn{1}{l}{(s.e.)}"                                  if n == 7  

replace all1_0 = "\multicolumn{1}{l}{Price (2020 USD)}"                        if n == 8


replace all1_0 = "\multicolumn{1}{l}{$ N $}"                           		   if n == 9  
replace all1_0 = "\multicolumn{1}{l}{Average $ A_i $ }"               		   if n == 10  

order all1_0 all0and all1 all1and all2 all2and all3 all3and all4 all4and all5 all5and all6 all6and all7 all7and  all8 all8and n
replace all8and = "\\" 
replace all8and = "\\ \bottomrule \end{tabular}"  if n == 10
replace all8and = " "                             if n == 1

// parenthesis for standard errors
foreach num of numlist 1(1)7 {
	replace all`num'and = ") & ("   if n == 5 | n == 7  
}
replace all0and = "& ("    	        if n == 5 | n == 7  
replace all8and = ") \\ \\"         if n == 5 | n == 7  
replace all8and = "  \\ \\"         if n == 8  
replace all8and = "\\ \cmidrule(l{.6cm}r{.4cm}){2-5} \cmidrule(l{.3cm}r{.3cm}){6-9}" if n == 2

// put together in string
gen all = " "
foreach num of numlist 1(1)8 {
	gen      all`num'b = all`num' if n == 9 | n == 8 
	tostring all`num' , replace force format(%15.3fc)
	replace  all`num' = ""        if n == 9 | n == 8
	tostring all`num'b, replace force format(%15.0fc)
	replace  all`num'  = "" if all`num' == "."
	replace  all`num'b = "" if all`num'b == "."
}

global orderin all1_0 all0and
foreach num of numlist 1(1)8 {
	global orderin $orderin all`num' all`num'b all`num'and 
}
global orderin $orderin all`num'
order $orderin n

foreach var of varlist all1_0-all8and {
	replace  all = all + `var'
	replace  all`num' = "" if all`num' == "."
}

keep all
cd $output
outsheet using abortionsfine_ultra.tex, noquote nonames replace
