version 15.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 2

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// ready data
global dataready = "$storage/charls/dataready"
global tfrdata   = "$storage/ChineseCensus" 
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $tfrdata
// gdp
insheet using gdppercapita.csv, clear
foreach var of varlist v2-v53 {
	replace `var' = `var'*1.39 if v1 != "Income per person (fixed 2000 US$)"
}
mkmat v2-v53, matrix(gdp)
matrix gdp = gdp'
matrix gdp = gdp[1...,2...]
matrix colnames gdp = ChinaGDP HongKongGDP JapanGDP SouthKoreaGDP

gen year = 1959 + _n
keep if year <= 2010

keep if v1 == "China"
drop v1

mkmat *, matrix(all)
matrix all = all'
clear
svmat all

gen year = 1959 + _n
keep if year <= 2010

cd $output
#delimit
twoway  (scatter all1       year    , msymbol(circle) mcolor(gs0) xline(1979, lwidth(vvthick) lpattern(solid) lcolor(gs14)))	

	, 
		  xlabel(1960[5]1975 1979 1985[5]2010, angle(25) grid glcolor(gs14))
		  ylabel(100[1100]3400, angle(h) glcolor(gs14))
		  xtitle("Year") 
		  ytitle("GDP per Capita")
		  graphregion(color(white)) plotregion(fcolor(white));
#delimit cr
graph export gdp_china.eps, replace

cd $tfrdata
import excel populationgrowth.xls, sheet("Data") clear
keep if A == "China"
keep E-BI

foreach var of varlist * {
	destring `var', replace
}
mkmat *, matrix(all)
matrix all = all'
clear
svmat all

gen year = 1959 + _n
keep if year <= 2010

cd $output
#delimit
twoway  (scatter all1       year    , msymbol(circle) mcolor(gs0) xline(1979, lwidth(vvthick) lpattern(solid) lcolor(gs14)) yline(3.5, lcolor(gs14)))	

	, 
		  xlabel(1960[5]1975 1979 1985[5]2010, angle(25) grid glcolor(gs14))
		  ylabel(-1[1.5]3.5, angle(h) glcolor(gs14))
		  xtitle("Year") 
		  ytitle("Population Growth, %")
		  graphregion(color(white)) plotregion(fcolor(white));
#delimit cr
graph export popgrowth_china.eps, replace

cd $tfrdata
import excel totalpopulation.xls, sheet("Data") clear
keep if A == "China"
keep E-BI

foreach var of varlist * {
	destring `var', replace
}
mkmat *, matrix(all)
matrix all = all'
clear
svmat all

gen year = 1959 + _n
keep if year <= 2010
replace all1 = all1/1000000

cd $output
#delimit
twoway  (scatter all1       year    , msymbol(circle) mcolor(gs0) xline(1979, lwidth(vvthick) lpattern(solid) lcolor(gs14)) yline(1500, lcolor(gs14)))	

	, 
		  xlabel(1960[5]1975 1979 1985[5]2010, angle(25) grid glcolor(gs14))
		  ylabel(600[300]1500, angle(h) glcolor(gs14))
		  xtitle("Year") 
		  ytitle("Total Population, Millions")
		  graphregion(color(white)) plotregion(fcolor(white));
#delimit cr
graph export population_china.eps, replace
