version 15.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 2

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// ready data
global dataready = "$storage/charls/dataready"
global tfrdata   = "$storage/ChineseCensus" 
// output
global output    = "$projects/fduringcmorethanone_revision/output"

  
// World Bank
cd $tfrdata

// fertility
insheet using tfr_worldbank.csv, clear
rename v1 country 
keep   if country == "China"
drop country
mkmat *, matrix(China)
matrix China = China'
clear 
svmat  China
rename China1 tfrChina
gen year = _n + 1959

tempfile tfrChina 
save   "`tfrChina'", replace

// CHARLS general sample
cd $dataready
use charls_females.dta, clear

// regressions details
// first stage for reference
/*
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1
*/
/////////////////////////////////////////////////////////////////
xtset simpleID age
keep if children !=. & year !=. & age !=.

// TFR
// age groups
gen births = children - l.children
matrix tfr = J(31,1,.)
foreach year of numlist 1971(1)2010 {
	matrix tfr`year' = [.]
	foreach age of numlist 15(1)45 {
		summ births if year == `year' & age == `age'
		local mean = r(mean)
		matrix tfr`year' = [tfr`year' \ r(mean)]
	}
	matrix tfr`year' = tfr`year'[2...,1...]
	matrix colnames tfr`year' = y`year' 
	matrix tfr = [tfr,tfr`year']
}
matrix tfr = tfr[1...,2...]

clear
svmat tfr     , names(col)
gen age = _n + 14

// interpolate
foreach year of numlist 1972(1)2010 {
	local numy = `year' - 1
	foreach age of numlist 15(1)45 {
		replace y`year' = y`numy' if age == `age' & y`year' ==.
	}
}

drop age
collapse (sum) *
mkmat *, mat(tfr)
matrix tfr = tfr'

// this project's sample
cd $dataready
use data_interim_dyn, clear

// base sample
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
gen basesample = e(sample)

// TFR
// age groups
matrix tfr_main = J(31,1,.)
foreach year of numlist 1980(1)2010 {
	matrix tfr`year' = [.]
	foreach age of numlist 15(1)45 {
		summ dchildren if year == `year' & age == `age' & basesample == 1
		local mean = r(mean)
		matrix tfr`year' = [tfr`year' \ r(mean)]
	}
	matrix tfr`year' = tfr`year'[2...,1...]
	matrix colnames tfr`year' = y`year' 
	matrix tfr_main = [tfr_main,tfr`year']
}
matrix tfr_main = tfr_main[1...,2...]

clear
svmat tfr_main     , names(col)
gen age = _n + 14

// interpolate
foreach year of numlist 1981(1)2010 {
	local numy = `year' - 1
	foreach age of numlist 15(1)45 {
		replace y`year' = y`numy' if age == `age' & y`year' ==.
	}
}

drop age
collapse (sum) *
mkmat *, mat(tfr_main)
matrix tfr_main = tfr_main'

clear 
svmat  tfr_main
rename tfr_main1 tfr_main
gen year = _n + 1979
tempfile tfr_main
save   "`tfr_main'", replace

clear 
svmat tfr
rename tfr1 tfr
gen year = _n + 1970
tempfile tfr
save   "`tfr'", replace

use "`tfrChina'", clear

merge 1:1 year using "`tfr'"
drop if _merge == 2
drop _merge

merge 1:1 year using "`tfr_main'"
drop if _merge == 2
drop _merge

// bin years
egen yearbin = cut(year) if year <= 2010, at(1971(2)2010)
collapse tfr*, by(yearbin)
gen year = _n*2-1 + 1970 + .5
drop if year > 2000

foreach var of varlist tfrChina tfr tfr_main {
	summ   `var' if year >= 1980 & year <= 2000
	local m`var' = string(r(mean),"%15.2f")
}

# delimit
global box  text(5 1993 
	 "{bf:Average 1980-2000}" 
	 " "
	 "World Bank: `mtfrChina'"
	 "CHARLS, All: `mtfr'"	 
	 "CHARLS, Working Sample: `mtfr_main'"
         , size(small) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

cd $output
#delimit
twoway  (scatter tfrChina year if year <= 2000,          		   msize(medium) msymbol(circle)    mfcolor(white) mlcolor(gs7)  xline(1979 , lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(scatter tfr      year if year <= 2000,			           msize(medium) msymbol(square)    mfcolor(none)   mlcolor(gs0)  yline(1.5  , lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(scatter tfr_main year if year >= 1980 & year <= 2000,     msize(medium) msymbol(diamond)   mcolor(gs0)),
		 
		legend(label(2 "CHARLS, All") label(3 "CHARLS, Working Sample") label(1 "World Bank") cols(3) order(1 2 3))
		  
		  xlabel(1971[4]1991 1995[5]2000, angle(25) grid glcolor(gs14)) 
		  ylabel(1.5[1]5.5, angle(h) glcolor(gs14)) 
		  ytitle("Total Fertility Rate")
		  xtitle("Year")
		  graphregion(color(white)) plotregion(color(white)) $box;
#delimit cr
graph export tfr_corroborate.eps, replace
