version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 2

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// regressions details
// first stage for reference
# delimit
reghdfe  dchildren lfine lfinealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1
gen agefirstchild = birthyearchild1 - birthyear 
replace  agefirstchild =. if  agefirstchild < 10 |  agefirstchild > 50

gen     worksat20aux = 1 if works == 1 & age == 20 
replace worksat20aux = 0 if works == 0 & age == 20

bysort simpleID : egen worksmean   = mean(works) if age >= 20
bysort simpleID : egen worksmean20 = mean(works) if worksat20aux >= 20

bysort simpleID : egen agemax    = max(age)
gen     childrenthisperiod = children - l.children
replace childrenthisperiod = 1 if childrenthisperiod >= 1 & childrenthisperiod !=. 

gen     workschild5lastyear = 1 if childrenthisperiod == 1 & works == 1
replace workschild5lastyear = 0 if childrenthisperiod == 1 & works == 0
bysort simpleID : egen workdmeanb5 = mean(workschild5lastyear)

gen     workschild4lastyear = 1 if l.childrenthisperiod == 0 & works == 1
replace workschild4lastyear = 0 if l.childrenthisperiod == 0 & works == 0
bysort simpleID : egen workdmeanb4 = mean(workschild4lastyear)

gen     workschildlastyear = 1 if l2.childrenthisperiod == 0 & works == 1
replace workschildlastyear = 0 if l2.childrenthisperiod == 0 & works == 0
bysort simpleID : egen workdmeanb = mean(workschildlastyear)

gen     workschild2lastyear = 1 if l1.childrenthisperiod == 1 & works == 1
replace workschild2lastyear = 0 if l1.childrenthisperiod == 1 & works == 0
bysort simpleID : egen workdmeanb2 = mean(workschild2lastyear)

gen     workschild3lastyear = 1 if l2.childrenthisperiod == 1 & works == 1
replace workschild3lastyear = 0 if l2.childrenthisperiod == 1 & works == 0
bysort simpleID : egen workdmeanb3 = mean(workschild3lastyear)
keep if age == agemax

matrix all = J(1,2,.)
matrix colnames all = supply supplyse

matrix alln = J(1,2,.)
matrix colnames alln = supply supplyse

matrix alla = J(1,2,.)
matrix colnames alla = supply supplyse

local num = 0
foreach var of varlist worksmean workdmeanb5 workdmeanb4 workdmeanb workdmeanb2 workdmeanb3 {
	local num = `num' + 1
	reg `var', cluster(ageyeargroups)
	matrix `var'b  = e(b)
	matrix `var'se = e(V)
	
	matrix all`num' = [`var'b,`var'se]
	matrix colnames all`num' = supply supplyse
	mat_rapp all : all all`num'
}
matrix all = all[2...,1...]

clear
svmat all, names(col)
gen maxsupply = supply + 1.96*sqrt(supplyse)
gen minsupply = supply - 1.96*sqrt(supplyse)

gen num = _n

#delimit
twoway (bar supply num, color(black)      barw(.75) yline(.9  , lwidth(vvthick) lpattern(solid) lcolor(gs14))),

		  legend(label(1 "Exemptions")  
		         label(2 "Calendar Year") label(3 "Province")
		  order(1 2 3 4 5) row(1))
		  xlabel(1 "Any Year" 
			 2 "Gave Birth this Year"
			 3 "No Birth 1 Year Before"
			 4 "No Birth 2 Years Before"
			 5 "Gave Birth 1 Year Before"
			 6 "Gave Birth 2 Years Before", angle(10) grid glcolor(gs14)) 
		  ylabel(.5[.10].9, glcolor(gs14) angle(h)) 
		  ytitle("Probability of Supplying Labor"
			 "Women Age 15 to 45")
		  xtitle("Year")
		  graphregion(color(white)) plotregion(fcolor(white));
#delimit cr
cd $output
graph export flfp_description.eps, replace
