version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 2

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// regressions details
// first stage for reference
# delimit
reghdfe  dchildren lfine lfinealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1

gen agefirstchild = birthyearchild1 - birthyear 
replace  agefirstchild =. if  agefirstchild < 10 |  agefirstchild > 50

bysort simpleID : egen agemax    = max(age)
gen childrenthisperiod = children - l.children
replace childrenthisperiod = 1 if childrenthisperiod >= 1 & childrenthisperiod !=. 
keep if age == agemax

gen     childaddfirst = 0 if children == 1 
replace childaddfirst = 1 if children >= 2 & children !=. 

summ childaddfirst if firstchildgirl == 1
summ childaddfirst if firstchildgirl == 0

egen    birthyeargroups = cut(birthyear), at(1926(4)1972)
drop if birthyear > 1965

matrix all = J(1,6,.)
matrix colnames all = girl girlse boy boyse ratio ratiose
foreach num of numlist 1934(4)1962 {       
		reg  childaddfirst if birthyeargroups == `num' & firstchildgirl == 1, cluster(province_code)
		matrix   girl_`num' = e(b)
		matrix girlse_`num' = e(V)
		matrix girlse_`num' = sqrt(girlse_`num'[1,1])
		reg  childaddfirst if birthyeargroups == `num' & firstchildgirl == 0, cluster(province_code)
		matrix   boy_`num' = e(b)
		matrix boyse_`num' = e(V)
		matrix boyse_`num' = sqrt(boyse_`num'[1,1])
		
		reg firstchildgirl if birthyeargroups == `num', cluster(province_code)
		matrix   ratio_`num' = e(b)
		matrix ratiose_`num' = e(V)
		matrix ratiose_`num' = sqrt(ratiose_`num'[1,1])
		
		
		matrix all_`num' = [girl_`num',girlse_`num',boy_`num',boyse_`num',ratio_`num',ratiose_`num']
		matrix colnames all_`num' = girl girlse boy boyse ratio ratiose
		mat_rapp all : all all_`num'
}

clear 
svmat all, names(col)

foreach var in girl boy ratio {
	gen max`var' = `var' + 1*(`var'se)
	gen min`var' = `var' - 1*(`var'se)
}

drop if girl == .
drop if _n == 11
gen year = 4*_n - 1 + 1931 + 1.5

replace ratio = (1 - ratio)*205
cd $output
#delimit
twoway (function y = 105, range(1935 1964) lwidth(vvthick) lpattern(solid) lcolor(gs14))
       (line    ratio               year,   lcolor(black)  yline(100, lcolor(gs14)) yline(115, lcolor(gs14)))
       (scatter ratio               year,   msize(large) msymbol(circle) mcolor(black))
      
       
		, 
		  legend(label(3  "Observed Sex Ratio (Working Sample)")  label(1  "Natural Sex Ratio") order(3 1)
		  ring(0) position(2))
		  xlabel(1935[5]1960 1964, angle(25) grid glcolor(gs14)) 
		  ylabel(100[5]115, glcolor(gs14) angle(h)) 
		  ytitle("Sex Ratio at Birth, Boys for Every 100 Girls")
		  xtitle("Mother's Birth Year")
		  graphregion(color(white)) plotregion(fcolor(white)) ;
#delimit cr
graph export firstgirlfirstboy_ratio.eps, replace
