version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 2

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// ultrasound availability
rename    province_code province 
merge m:1 province using data_alz_jpe_ultracapitalcollapse
drop if _merge == 2
drop _merge

// interact fines with ultrasound 
gen     ultraind = 0 if ultra_capital !=. & year !=.
replace ultraind = 1 if year > ultra_cap & ultra_cap !=. & year !=.

xtset simpleID age
# delimit
ivreghdfe  dchildren (lfine =  lfinealt_exp) l.children,
	     absorb(i.simpleID i.ageyeargroups) cluster(segroup);
# delimit cr
gen basesample = e(sample)

// residualize variables from province times year times age
foreach var of varlist fine finealt_exp {
	reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
foreach var of varlist m_children f_children children {
	reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}

global u0 & ultraind == 0
global u1 & ultraind == 1 
global u2 & ultraind !=.

// elasticities by age
foreach u of numlist 2 {
	# delimit
	xtdpd L(0/1).m_children_resid L(0).(fine_resid) if lchildren >= 0 & lchildren <= . & age >= 15 & age <= 35 ${u`u'} & basesample == 1,
		 twostep dgmmiv(m_children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(m_children_resid L1.(fine_resid)) iv(finealt_exp_resid) nocons;
	# delimit cr
	matrix  bm_a_u`u'  = e(b)[1,2]
	matrix sem_a_u`u' = sqrt(e(V)[2,2])
	
	# delimit cr
	foreach num of numlist 20(1)40 {
		local numy1 = `num' - 5
		local numy2 = `num' + 5
		
		# delimit
		xtdpd L(0/1).children_resid L(0).(fine_resid) if lchildren >= 1 & lchildren <= . & firstchildgirl == 0 & age >= `numy1' & age <= `numy2' ${u`u'},
				 twostep dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) iv(finealt_exp_resid) nocons;
		# delimit cr
		matrix  b1_a`num'_u`u'  = e(b)[1,2]
		matrix se1_a`num'_u`u' = sqrt(e(V)[2,2])
		
		# delimit
		xtdpd L(0/1).children_resid L(0).(fine_resid) if lchildren >= 1 & lchildren <= . & firstchildgirl == 1 & age >= `numy1' & age <= `numy2'  ${u`u'},
				 twostep dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid))  iv(finealt_exp_resid) nocons;
		# delimit cr
		matrix  b2_a`num'_u`u'  = e(b)[1,2]
		matrix se2_a`num'_u`u' = sqrt(e(V)[2,2])
		
		# delimit
		xtdpd L(0/1).m_children_resid L(0).(fine_resid) if lchildren >= 0 & lchildren <= . & age >= `numy1' & age <= `numy2' ${u`u'} & basesample == 1,
				 twostep dgmmiv(m_children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(m_children_resid L1.(fine_resid)) iv(finealt_exp_resid) nocons;
		# delimit cr
		matrix  b3_a`num'_u`u'  = e(b)[1,2]
		matrix se3_a`num'_u`u' = sqrt(e(V)[2,2])
		
		# delimit
		xtdpd L(0/1).f_children_resid L(0).(fine_resid) if lchildren >= 0 & lchildren <= . & age >= `numy1' & age <= `numy2' ${u`u'} & basesample == 1,
				 twostep dgmmiv(f_children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(f_children_resid L1.(fine_resid)) iv(finealt_exp_resid) nocons;
		# delimit cr
		matrix  b4_a`num'_u`u'  = e(b)[1,2]
		matrix se4_a`num'_u`u' = sqrt(e(V)[2,2])
	}
}

// plots
cd $output
clear
foreach u of numlist 2 {
	foreach est in b se {
		foreach numy of numlist 1 2 3 4 {
		matrix `est'`numy'_u`u'_a = [.]
			foreach num of numlist 20(1)40 {
				matrix `est'`numy'_u`u'_a = [`est'`numy'_u`u'_a \ `est'`numy'_a`num'_u`u']
			}
			matrix `est'`numy'_u`u'_a = `est'`numy'_u`u'_a[2...,1]
			svmat  `est'`numy'_u`u'_a
			rename `est'`numy'_u`u'_a1 `est'`numy'_u`u'_a
		}
	}
}
gen age = _n + 19

// construct intervals
foreach u of numlist 2 {
	foreach numy of numlist 1 2 { 
		gen max`numy'_u`u'_a = b`numy'_u`u'_a + 1.96*se`numy'_u`u'_a
		gen min`numy'_u`u'_a = b`numy'_u`u'_a - 1.96*se`numy'_u`u'_a
	}
}

#delimit
twoway  (lowess    b1_u2_a age                if age >= 20 & age <= 40, lcolor(gs9) lwidth(medthick) bwidth(.8))
		(rcap      max1_u2_a min1_u2_a age    if age >= 20 & age <= 40, lcolor(gs9))
		(scatter   b1_u2_a age                if age >= 20 & age <= 40, msymbol(circle) color(gs9)  msize(small))
		
		(lowess    b2_u2_a age                if age >= 20 & age <= 40, lcolor(gs3) lwidth(medthick) bwidth(.8)   yline(0    , lpattern(dash)  lcolor(gs0) lwidth(thin)))
		(rcap      max2_u2_a min2_u2_a age    if age >= 20 & age <= 40, lcolor(gs3))
		(scatter   b2_u2_a age                if age >= 20 & age <= 40, msymbol(square) color(gs3)  msize(small)),
		
		legend(label(3 "Flow of Children, First-Child Boy")  label(1 "Smooth Trend") 
			   label(6 "Flow of Children, First-Child Girl") label(4 "Smooth Trend")  rows(2) order(6 4 3 1))

		  xlabel(20[4]40, angle(0) grid glcolor(gs14)) 
		  ylabel(.25[.25]-.75, angle(h) glcolor(gs14)) 
		  ytitle("Price Semi-Elasticity")
		  xtitle("Age")
		  graphregion(color(white)) plotregion(color(white));
#delimit cr
graph export childrenfine_elasticityfirstgirl.eps, replace

// smooth spiky male points
foreach u of numlist 2 {
	replace  b3_u`u'_a =  bm_a_u`u'[1,1] if age <= 25
	replace se3_u`u'_a = sem_a_u`u'[1,1] if age <= 25

	foreach numy of numlist 3 4 { 
		gen max`numy'_u`u'_a = b`numy'_u`u'_a + 1.96*se`numy'_u`u'_a
		gen min`numy'_u`u'_a = b`numy'_u`u'_a - 1.96*se`numy'_u`u'_a
	}
}

#delimit
twoway  (lowess    b3_u2_a age                if age >= 20 & age <= 40, lcolor(gs9) lwidth(medthick) bwidth(.8))
		(rcap      max3_u2_a min3_u2_a age    if age >= 20 & age <= 40, lcolor(gs9))
		(scatter   b3_u2_a age                if age >= 20 & age <= 40, msymbol(circle) color(gs9)  msize(small))
		
		(lowess    b4_u2_a age                if age >= 20 & age <= 40, lcolor(gs3) lwidth(medthick) bwidth(.8)   yline(0    , lpattern(dash)  lcolor(gs0) lwidth(thin)))
		(rcap      max4_u2_a min4_u2_a age    if age >= 20 & age <= 40, lcolor(gs3))
		(scatter   b4_u2_a age                if age >= 20 & age <= 40, msymbol(square) color(gs3)  msize(small)),
		
		legend(label(3 "Flow of Boys")  label(1 "Smooth Trend") 
			   label(6 "Flow of Girls") label(4 "Smooth Trend")  rows(2) order(6 4 3 1))

		  xlabel(20[4]40, angle(0) grid glcolor(gs14)) 
		  ylabel(.05[.05]-.15, angle(h) glcolor(gs14)) 
		  ytitle("Price Semi-Elasticity")
		  xtitle("Age")
		  graphregion(color(white)) plotregion(color(white));
#delimit cr
graph export childrenfine_elasticitygenderstalks.eps, replace
