version 15.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1200

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// ready data
global dataready = "$storage/charls/dataready"
global tfrdata   = "$storage/ChineseCensus" 
// output
global output    = "$projects/fduringcmorethanone_revision/output"

// run bootstrap
foreach b of numlist 1(1)$bootstraps {
	cd $dataready
	use data_interim_dyn.dta, clear
	drop segroup
	egen segroup       = group(province_code birthyear)
	keep simpleID segroup
	duplicates drop simpleID, force
	bsample, strata(segroup)
	drop segroup
	gen simpleIDalt = _n
	expand 166
	bysort simpleIDalt : egen age = seq()
	replace age = age - 63
	merge m:m simpleID age using data_interim_dyn
	keep if _merge == 3
	drop simpleID _merge
	rename simpleIDalt simpleID
	xtset simpleID age
	keep if year >= 1990 & year <= 2000

	// base sample
	# delimit
	reghdfe  l.fine l.finealt_exp,
			 absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
	# delimit cr
	gen basesample = e(sample)

	// residualize variables from province times year times age
	foreach var of varlist fine finealt_exp {
		reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
	}
	foreach var of varlist m_children f_children children {
		reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
	}
	gen dm_children_cf = dm_children if basesample == 1
	gen df_children_cf = df_children if basesample == 1
		
	foreach num of numlist 20(1)40 {
		local numy1 = `num' - 5
		local numy2 = `num' + 5
		
		# delimit
		xtdpd L(0/1).f_children_resid L(0).(fine_resid) if lchildren >= 0 & lchildren <= . & age >= `numy1' & age <= `numy2' & basesample == 1,
				 twostep dgmmiv(f_children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(f_children_resid L1.(fine_resid)) iv(finealt_exp_resid) nocons;
		# delimit cr
		replace df_children_cf = df_children_cf - e(b)[1,2]*lfine if age == `num' & e(sample) == 1
	}

	// focus on second decade
	foreach var of varlist dm_children dm_children_cf df_children df_children_cf {
		matrix `var'cf = [.]
		foreach age of numlist 15(1)45 {
			summ   `var' if age == `age' & basesample == 1
			matrix `var'cf = [`var'cf \ r(mean)]
		}
		matrix `var'cf = `var'cf[2...,1...]
		matrix colnames `var'cf = `var'cf
		svmat  `var'cf, names(col)
	}
	keep dm_childrencf dm_children_cfcf df_childrencf df_children_cfcf
	drop if dm_childrencf == .

	// rename and generate total
	foreach var in dm_children dm_children_cf df_children df_children_cf {
		rename `var'cf `var'
	}
	gen dchildren    = dm_children    + df_children
	gen dchildren_cf = dm_children_cf + df_children_cf

	// plot
	gen     age = _n + 15
	replace age = 15 if age ==.

	// generate cumulative
	foreach var of varlist d*{ 
		gen     cum`var' = sum(`var') 
	} 

	summ  cumdchildren if age == 42
	matrix tfr_b`b' = r(mean)
	summ  cumdchildren_cf if age == 42
	matrix tfr_cf_b`b' = r(mean)
	matrix diff_b`b' = tfr_b`b'[1,1] - tfr_cf_b`b'[1,1]
}

// organize bootstraps
foreach var in tfr tfr_cf diff {
	clear
	foreach b of numlist 1(1)$bootstraps {
		svmat     `var'_b`b', names(col)
		rename c1 `var'_b`b'
	}
	egen `var'_p10 = rowpctile(`var'_b*), p(10)
	egen `var'_p90 = rowpctile(`var'_b*), p(90)
	
	foreach vary of varlist `var'_b* {
		replace `vary' =. if `vary' < `var'_p10 | `vary' > `var'_p90 
	}
	egen   `var'_se = rowsd(`var'_b*)
	summ   `var'_se
	matrix se`var'  = r(mean)
	local  se`var'  = string(se`var'[1,1],"%15.2f") 
}

// this project's sample
cd $dataready
use data_interim_dyn, clear
keep if year >= 1990 & year <= 2000

// base sample
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
gen basesample = e(sample)

// residualize variables from province times year times age
foreach var of varlist fine finealt_exp {
	reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
foreach var of varlist m_children f_children children {
	reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
gen dm_children_cf = dm_children if basesample == 1
gen df_children_cf = df_children if basesample == 1
	
foreach num of numlist 20(1)40 {
	local numy1 = `num' - 5
	local numy2 = `num' + 5
	
	# delimit
	xtdpd L(0/1).f_children_resid L(0).(fine_resid) if lchildren >= 0 & lchildren <= . & age >= `numy1' & age <= `numy2' & basesample == 1,
			 twostep dgmmiv(f_children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(f_children_resid L1.(fine_resid)) iv(finealt_exp_resid) nocons;
	# delimit cr
	replace df_children_cf = df_children_cf - e(b)[1,2]*lfine if age == `num' & e(sample) == 1
}

foreach var of varlist dm_children dm_children_cf df_children df_children_cf {
	matrix `var'cf = [.]
	foreach age of numlist 15(1)45 {
		summ   `var' if age == `age' & basesample == 1
		matrix `var'cf = [`var'cf \ r(mean)]
	}
	matrix `var'cf = `var'cf[2...,1...]
	matrix colnames `var'cf = `var'cf
	svmat  `var'cf, names(col)
}
keep dm_childrencf dm_children_cfcf df_childrencf df_children_cfcf
drop if dm_childrencf == .

// rename and generate total
foreach var in dm_children dm_children_cf df_children df_children_cf {
	rename `var'cf `var'
}
gen dchildren    = dm_children + df_children
gen dchildren_cf = dm_children_cf + df_children_cf

// plot
gen     age = _n + 15
replace age = 15 if age ==.

// generate cumulative
foreach var of varlist d*{ 
	gen     cum`var' = sum(`var') 
} 

summ  cumdchildren if age == 42
matrix tfr = r(mean)
local tfr   = string(tfr[1,1],"%15.2f")
summ  cumdchildren_cf if age == 42
matrix tfr_cf = r(mean)
local  tfr_cf = string(tfr_cf[1,1],"%15.2f")

matrix diff = abs(tfr[1,1] - tfr_cf[1,1])
local  diff = string(diff[1,1],"%15.2f") 

# delimit
global box1 text(.75 35.5
	 "{bf:Total Fertility Rate}" 
	 "(Cumulative at Age 45)"
	 " "
	 "Realized: `tfr' (s.e `setfr')"
	 " "
	 "No Policy: `tfr_cf' (s.e `setfr_cf')"
	 " "
	 "Difference: `diff' (s.e `sediff') "
         , size(small) place(c) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

cd $output
#delimit
twoway  (scatter   cumdchildren     age, msymbol(circle)                 color(gs0)  msize(medlarge))
		(scatter   cumdchildren_cf  age, msymbol(square) mfcolor(none) mlcolor(gs7)  msize(medlarge)),
		
		legend(label(1 "Realized")
			   label(2 "No Policy") rows(1) order(1 2))

		  xlabel(16 20[5]45,  angle(0) grid glcolor(gs14)) 
		  ylabel(0[.7]2.8, angle(h) glcolor(gs14)) 
		  ytitle("Cumulative Age-Specific Fertility Rate")
		  xtitle("Age")
		  graphregion(color(white)) plotregion(color(white)) $box1;
#delimit cr
graph export childrenfine_counterfactual_sd.eps, replace
