version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 2

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// base sample
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
gen basesample = e(sample)

// residualize variables from province times year times age
foreach var of varlist fine finealt_exp {
	reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
foreach var of varlist children {
	reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
xtdpd L(0/1).children_resid L(0).(fine_resid) if basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)

// convert prices into 2020 dollars
foreach var of varlist lffine lffinealt_exp {
	replace `var' = exp(`var')*4.5*1.19*326.027
}

global group_1  if urban == 0
global group_2  if urban == 1 
global group_3  if aghukou == 1 
global group_4  if aghukou == 0

global group_5  if exe1 == 1       // minority
global group_6  if exe1 != 1       // non-minority
global group_7  if worksoe == 2    // no work soe
global group_8  if worksoe == 1    // work soe

global group_9  if exe4 == 0      // no job difficulty
global group_10 if exe4 == 1      // job difficulty 
global group_11 if exe5 == 0      // no male scarcity
global group_12 if exe5 == 1      // scarcity 

global group_13  if noschool     == 1
global group_14  if elementary   == 1
global group_15  if middleschool == 1
global group_16  if highschool   == 1

global group_17 if year >= 1980 & year <= 1984
global group_18 if year >= 1985 & year <= 1989
global group_19 if year >= 1990 & year <= 1994
global group_20 if year >= 1995 & year <= 2000

xtset simpleID age
foreach num of numlist 1(1)20 {
	# delimit
	xtdpd L(0/1).children_resid L(0).(fine_resid) ${group_`num'} & basesample == 1, 
				dgmmiv(children_resid) 
				dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) 
				nocons twostep vce(robust) iv(finealt_exp_resid);
	# delimit cr
	matrix   b1_m`num'  = e(b)[1,2]
	matrix  se1_m`num'  = sqrt(e(V)[2,2])
	summ   dchildren if e(sample) == 1
	matrix mean = r(mean)
	nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
	matrix  b2_m`num'  = r(b)[1,1]
	matrix  se2_m`num'  = sqrt(r(V)[1,1])
	summ lffine if e(sample) == 1
	matrix  price_m`num' = r(mean)
	xtdes if e(sample) == 1
	matrix   N_m`num'    = r(N)
	matrix   T_m`num'    = r(mean) 

	matrix m`num' = [b1_m`num',se1_m`num',b2_m`num',se2_m`num',price_m`num',N_m`num',T_m`num']'
}
matrix place1 = J(1,4,.)
matrix place2 = J(2,4,.)
matrix place3 = J(3,4,.)
matrix place4 = J(4,4,.)
matrix all = [place3 \ [m1,m2,m3,m4] \ place2 \ [m5,m6,m7,m8] \ place2 \ [m9,m10,m11,m12] \ place2 \ [m13,m14,m15,m16] \ place2 \ [m17,m18,m19,m20]]
clear
svmat all

gen n = _n
foreach var of varlist all* {
	format  `var' %15.3fc
	replace `var' = round(`var',.001) 
	gen    `var'and = "&" if n !=1
}

gen all0and = "&" if n != 1
gen     all1_0 = "\begin{tabular}{ L{2.5cm} C{3cm} C{3cm} C{3cm} C{3cm} } \toprule" if n == 1

replace all1_0  = "\multicolumn{5}{l}{\textbf{\textit{Panel a.} Sector.}}"  													            if n == 2
replace all1_0  = "& \underline{Rural} & \underline{Urban} & \underline{Agricultural} & \underline{Non-Agricultural}"                       if n == 3

replace all0and = " "       													if n == 2 | n == 3 | n == 11 | n == 12 | n == 20 | n == 21 | n == 29 | n == 30 | n == 38 | n == 39
replace all1and = "   "           						      					if n == 2 | n == 3 | n == 11 | n == 12 | n == 20 | n == 21 | n == 29 | n == 30 | n == 38 | n == 39  
replace all2and = "   "           						      					if n == 2 | n == 3 | n == 11 | n == 12 | n == 20 | n == 21 | n == 29 | n == 30 | n == 38 | n == 39 
replace all3and = "   "       													if n == 2 | n == 3 | n == 11 | n == 12 | n == 20 | n == 21 | n == 29 | n == 30 | n == 38 | n == 39  

replace all1_0 =  "\multicolumn{1}{l}{Semi-Elastcity: $ \hat{\gamma}_{\Xi} $}"   if n == 4  | n == 13 | n == 22 | n == 31 | n == 40 
replace all1_0 = "\multicolumn{1}{l}{(s.e.)}"                                    if n == 5  | n == 14 | n == 23 | n == 32 | n == 41

replace all1_0 = "\multicolumn{1}{l}{Elasticity}"                                if n == 6  | n == 15 | n == 24 | n == 33 | n == 42 
replace all1_0 = "\multicolumn{1}{l}{(s.e.)}"                          			 if n == 7  | n == 16 | n == 25 | n == 34 | n == 43

replace all1_0 = "\multicolumn{1}{l}{Price (2020 USD)}"                      	 if n == 8  | n == 17 | n == 26 | n == 35 | n == 44 

replace all1_0 = "\multicolumn{1}{l}{$ N $}"                           			 if n == 9  | n == 18 | n == 27 | n == 36 | n == 45
replace all1_0 = "\multicolumn{1}{l}{Average $ A_i $ }"                			 if n == 10 | n == 19 | n == 28 | n == 37 | n == 46

replace all1_0  = "\multicolumn{5}{l}{\textbf{\textit{Panel b.} Ethnicity and Employment Source.}}"  	             if n == 11
replace all1_0  = "& \underline{Non-Han} & \underline{Han} & \underline{Not SE Worker} & \underline{SE Worker}"      if n == 12

replace all1_0  = "\multicolumn{5}{l}{\textbf{\textit{Panel c.} Economic Hardship and Male Presence in the Family.}}"  			               if n == 20
replace all1_0  = "& \underline{No Job Difficulty} & \underline{Job Difficulty} & \underline{No Male Scarcity} & \underline{Male Scarcity}"    if n == 21

replace all1_0  = "\multicolumn{5}{l}{\textbf{\textit{Panel d.} Education.}}"  											           			   if n == 29
replace all1_0  = "& \underline{None} & \underline{Elementary} & \underline{Middle School} & \underline{High School}"                          if n == 30

replace all1_0  = "\multicolumn{5}{l}{\textbf{\textit{Panel d.} Calendar Years.}}"  											  			   if n == 38
replace all1_0  = "& \underline{1980-1984} & \underline{1985-1989} & \underline{1990-1994} & \underline{1995-2000}"                            if n == 39

order all1_0 all0and all1 all1and all2 all2and all3 all3and all4 all4and n
replace all4and = "\\" 
replace all4and = "\\ \bottomrule \end{tabular}"  if n == 46
replace all4and = " "                             if n == 1

// parenthesis for standard errors
foreach num of numlist 1(1)3 {
	replace all`num'and = ") & ("   if n == 5 | n == 7 | n == 14 | n == 16 | n == 23 | n == 25 | n == 32 | n == 34  | n == 41 | n == 43
}

replace all0and = "& ("             if n == 5  | n == 7  | n == 14 | n == 16 | n == 23 | n == 25 | n == 32 | n == 34 | n == 41 | n == 43
replace all4and = ") \\ \\"         if n == 5  | n == 7  | n == 14 | n == 16 | n == 23 | n == 25 | n == 32 | n == 34 | n == 41 | n == 43
replace all4and = "\\ \midrule"     if n == 10 | n == 19 | n == 28 | n == 37
replace all4and = "\\ \\"           if n == 8  | n == 17 | n == 26 | n == 35 | n == 44

// put together in string
gen all = " "
foreach num of numlist 1(1)4 {
	gen      all`num'b = all`num' if n == 9 | n == 18 | n == 27 | n == 36 | n == 45 | n == 8  | n == 17 | n == 26 | n == 35 | n == 44 
	tostring all`num' , replace force format(%15.3fc)
	replace  all`num' = ""        if n == 9 | n == 18 | n == 27 | n == 36 | n == 45 | n == 8  | n == 17 | n == 26 | n == 35 | n == 44 
	tostring all`num'b, replace force format(%15.0fc)
	replace  all`num'  = "" if all`num' == "."
	replace  all`num'b = "" if all`num'b == "."
}

global orderin all1_0 all0and
foreach num of numlist 1(1)4 {
	global orderin $orderin all`num' all`num'b all`num'and 
}
global orderin $orderin all`num'
order $orderin n

foreach var of varlist all1_0-all4and {
	
	replace  all = all + `var'
	replace  all`num' = "" if all`num' == "."
}

keep all
cd $output
outsheet using childrenfine_heterogeneity.tex, noquote nonames replace
