version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1200

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// with proportional proces and with lump-sum prices
gen     lump = 0 if province_name != " "
replace lump = 1 if province_name == "Beijing"           & year > 1992
replace lump = 1 if province_name == "Hebei"             & year > 1989
replace lump = 1 if province_name == "Inner Mongolia"    & year > 1995
replace lump = 1 if province_name == "Liaoning"          & year > 1992
replace lump = 1 if province_name == "Shanghai"          & year > 1992
replace lump = 1 if province_name == "Jiangsu"           & year > 1990
replace lump = 1 if province_name == "Fujian"            & year > 1991
replace lump = 1 if province_name == "Jiangxi"           
replace lump = 1 if province_name == "Shandong"          
replace lump = 1 if province_name == "Guangdong"         & year > 1992
replace lump = 1 if province_name == "Guangxi"

// base sample
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
gen basesample = e(sample)

// residualize variables from province times year times age
foreach var of varlist fine finealt_exp works {
	reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
foreach var of varlist lchildren children {
	reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}

// set flows as indicators
foreach var of varlist dchildren { 
	replace `var' = 1 if `var' > 1 & `var' !=.
}

/////////////////////////////////////////////////////////////////
xtset simpleID age
// first block
// base
reghdfe  dchildren lfine l.children if basesample == 1, noabsorb cluster(segroup)
matrix  b1_m2  = e(b)[1,1]
matrix  b2_m2  = e(b)[1,2]
matrix  se1_m2 = sqrt(e(V)[1,1])
matrix  se2_m2 = sqrt(e(V)[2,2])


// base, levels
gen lfinelevel = exp(lfine) - 1
reghdfe  dchildren lfinelevel l.children if basesample == 1, noabsorb cluster(segroup)
matrix  b1_m2  = e(b)[1,1]
matrix  b2_m2  = e(b)[1,2]
matrix  se1_m2 = sqrt(e(V)[1,1])
matrix  se2_m2 = sqrt(e(V)[2,2])
