version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1200

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// with proportional proces and with lump-sum prices
gen     lump = 0 if province_name != " "
replace lump = 1 if province_name == "Beijing"           & year > 1992
replace lump = 1 if province_name == "Hebei"             & year > 1989
replace lump = 1 if province_name == "Inner Mongolia"    & year > 1995
replace lump = 1 if province_name == "Liaoning"          & year > 1992
replace lump = 1 if province_name == "Shanghai"          & year > 1992
replace lump = 1 if province_name == "Jiangsu"           & year > 1990
replace lump = 1 if province_name == "Fujian"            & year > 1991
replace lump = 1 if province_name == "Jiangxi"           
replace lump = 1 if province_name == "Shandong"          
replace lump = 1 if province_name == "Guangdong"         & year > 1992
replace lump = 1 if province_name == "Guangxi"

// base sample
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
gen basesample = e(sample)

// residualize variables from province times year times age
foreach var of varlist fine finealt_exp works {
	reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
foreach var of varlist lchildren children {
	reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}

// set flows as indicators
foreach var of varlist dchildren { 
	replace `var' = 1 if `var' > 1 & `var' !=.
}

/////////////////////////////////////////////////////////////////
xtset simpleID age
// first block
// base
reghdfe  dchildren lfine l.children if basesample == 1, noabsorb cluster(segroup)
matrix  b1_m2  = e(b)[1,1]
matrix  b2_m2  = e(b)[1,2]
matrix  se1_m2 = sqrt(e(V)[1,1])
matrix  se2_m2 = sqrt(e(V)[2,2])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[lfine]*100*log(1.01))/mean[1,1]
matrix  b3_m2  = r(b)[1,1]
matrix  se3_m2  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m2    = r(N)
matrix   T_m2    = r(mean) 
	
// logit 
logit    dchildren lfine lchildren if basesample == 1, vce(cluster segroup) 
margins, dydx(lfine lchildren) atmeans
matrix  b1_m1  = r(b)[1,1]
matrix  b2_m1  = r(b)[1,2]
matrix  se1_m1 = sqrt(r(V)[1,1])
matrix  se2_m1 = sqrt(r(V)[2,2])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
matrix   b3_m1 = b1_m1[1,1]*(100*log(1.01)/mean[1,1])
matrix  se3_m1 = se1_m1[1,1]*(100*log(1.01)/mean[1,1])

xtdes if e(sample) == 1
matrix   N_m1    = r(N)
matrix   T_m1    = r(mean) 

// transformed
reghdfe  children lfine l.children if basesample == 1, noabsorb cluster(segroup)
matrix   b1_m3  = e(b)[1,1]
matrix  se1_m3  = sqrt(e(V)[1,1])

nlcom _b[l.children] - 1
matrix  b2_m3  = r(b)[1,1]
matrix  se2_m3  = sqrt(r(V)[1,1])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[lfine]*100*log(1.01))/mean[1,1]
matrix  b3_m3  = r(b)[1,1]
matrix  se3_m3  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m3    = r(N)
matrix   T_m3    = r(mean) 

// account for invariante stuff
reghdfe  children lfine l.children if basesample == 1, absorb(ageyeargroups) cluster(segroup)
matrix   b1_m4  = e(b)[1,1]
matrix  se1_m4  = sqrt(e(V)[1,1])
nlcom _b[l.children] - 1
matrix  b2_m4   = r(b)[1,1]
matrix  se2_m4  = sqrt(r(V)[1,1])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[lfine]*100*log(1.01))/mean[1,1]
matrix  b3_m4   = r(b)[1,1]
matrix  se3_m4  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m4    = r(N)
matrix   T_m4    = r(mean) 

// add up to four lagabertos 
xtdpd L(0/1).children_resid L(0).(fine_resid) if basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust)
matrix   b1_m5  = e(b)[1,2]
matrix  se1_m5  = sqrt(e(V)[2,2])
nlcom _b[l.children] - 1
matrix  b2_m5  = r(b)[1,1]
matrix  se2_m5  = sqrt(r(V)[1,1])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
matrix  b3_m5  = r(b)[1,1]
matrix  se3_m5  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m5    = r(N)
matrix   T_m5    = r(mean) 

// add up to four lagabertos 
xtdpd L(0/4).children_resid L(0).(fine_resid) if basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust)
matrix   b1_m6  = e(b)[1,5]
matrix  se1_m6  = sqrt(e(V)[5,5])
nlcom _b[l.children] - 1
matrix  b2_m6  = r(b)[1,1]
matrix  se2_m6  = sqrt(r(V)[1,1])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
matrix  b3_m6  = r(b)[1,1]
matrix  se3_m6  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m6    = r(N)
matrix   T_m6    = r(mean) 

// account for measurement error
xtdpd L(0/1).children_resid L(0).(fine_resid) if basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)
matrix   b1_m7  = e(b)[1,2]
matrix  se1_m7  = sqrt(e(V)[2,2])
nlcom _b[l.children] - 1
matrix  b2_m7  = r(b)[1,1]
matrix  se2_m7  = sqrt(r(V)[1,1])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
matrix  b3_m7  = r(b)[1,1]
matrix  se3_m7  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m7    = r(N)
matrix   T_m7    = r(mean) 

// second block
// controls
# delimit
global X0 factor_population  factor_agriculture factor_transportation factor_industry 
          factor_employment  factor_trade  
	      factor_govbanking  factor_economicorganization factor_subsidies
	      factor_education   factor_economy;
# delimit cr 

# delimit
global X1 l.factor_population  l.factor_agriculture l.factor_transportation l.factor_industry 
          l.factor_employment  l.factor_trade  
	      l.factor_govbanking  l.factor_economicorganization l.factor_subsidies
	      l.factor_education   l.factor_economy;
# delimit cr

# delimit
global X2 l2.factor_population  l2.factor_agriculture l2.factor_transportation l2.factor_industry 
          l2.factor_employment  l2.factor_trade  
	      l2.factor_govbanking  l2.factor_economicorganization l2.factor_subsidies
	      l2.factor_education   l2.factor_economy;
# delimit cr
global set8  $X0 
global set9  $X0 $X1 
global set10 $X0 $X1 $X2

foreach num of numlist 8(1)10 {
	xtdpd L(0/1).children_resid L(0).(fine_resid) ${set`num'} if basesample == 1,dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid) div(${set`num'})
	matrix   b1_m`num'  = e(b)[1,2]
	matrix  se1_m`num'  = sqrt(e(V)[2,2])
	nlcom _b[l.children] - 1
	matrix  b2_m`num'  = r(b)[1,1]
	matrix  se2_m`num'  = sqrt(r(V)[1,1])
	
	summ   dchildren if e(sample) == 1
	matrix mean = r(mean)
	nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
	matrix  b3_m`num'  = r(b)[1,1]
	matrix  se3_m`num'  = sqrt(r(V)[1,1])
	
	xtdes if e(sample) == 1
	matrix   N_m`num'    = r(N)
	matrix   T_m`num'    = r(mean) 
}

// proportional
xtdpd L(0/1).children_resid L(0).(fine_resid) if lump == 0 & basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)
matrix   b1_m11  = e(b)[1,2]
matrix  se1_m11  = sqrt(e(V)[2,2])
nlcom _b[l.children] - 1
matrix  b2_m11  = r(b)[1,1]
matrix  se2_m11  = sqrt(r(V)[1,1])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
matrix  b3_m11  = r(b)[1,1]
matrix  se3_m11  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m11    = r(N)
matrix   T_m11    = r(mean) 

// lump
xtdpd L(0/1).children_resid L(0).(fine_resid) if lump == 1 & basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)
matrix   b1_m12  = e(b)[1,2]
matrix  se1_m12  = sqrt(e(V)[2,2])
nlcom _b[l.children] - 1
matrix  b2_m12  = r(b)[1,1]
matrix  se2_m12  = sqrt(r(V)[1,1])

summ   dchildren if e(sample) == 1
matrix mean = r(mean)
nlcom (_b[fine_resid]*100*log(1.01))/mean[1,1]
matrix  b3_m12  = r(b)[1,1]
matrix  se3_m12  = sqrt(r(V)[1,1])

xtdes if e(sample) == 1
matrix   N_m12    = r(N)
matrix   T_m12    = r(mean) 

// works analagous
xtdpd L(0/1).works_resid    L(0).(fine_resid)             if basesample == 1, dgmmiv(works_resid)    dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(works_resid    L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)
matrix   b1_m13  = e(b)[1,2]
matrix  se1_m13  = sqrt(e(V)[2,2])
matrix  b2_m13   = .
matrix  se2_m13   = .

matrix  b3_m13  = .
matrix  se3_m13  = .

xtdes if e(sample) == 1
matrix   N_m13    = r(N)
matrix   T_m13    = r(mean) 

// works analogous with children
xtdpd L(0/1).works_resid    L(0).(fine_resid lchildren_resid)  if basesample == 1, dgmmiv(works_resid) dgmmiv(L2.(fine_resid lchildren_resid), lag(1 .)) lgmmiv(works_resid    L1.(fine_resid lchildren_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)
matrix   b1_m14  = e(b)[1,2]
matrix  se1_m14  = sqrt(e(V)[2,2])
nlcom _b[lchildren_resid] - 1
matrix  b2_m14  = r(b)[1,1]
matrix  se2_m14  = sqrt(r(V)[1,1])

matrix  b3_m14  = .
matrix  se3_m14  = .

xtdes if e(sample) == 1
matrix   N_m14    = r(N)
matrix   T_m14    = r(mean) 

// organize matrix of all estimates in first block
foreach num of numlist 1(1)14 {
	matrix m`num' = [b1_m`num',se1_m`num',b3_m`num',se3_m`num',b2_m`num',se2_m`num',N_m`num',T_m`num']'
}

matrix place3 = J(3,7,.)
matrix all = [place3 \ [m1,m2,m3,m4,m5,m6,m7] \ place3 \ [m8,m9,m10,m11,m12,m13,m14]] 
clear
svmat all

gen n = _n
foreach var of varlist all* {
	format  `var' %15.3fc
	replace `var' = round(`var',.001) 
	gen    `var'and = "&" if n !=1
}

gen all0and = "&" if n != 1
gen     all1_0 = "\begin{tabular}{ L{2cm} C{3.75cm} C{3.75cm} C{3.75cm} C{3.75cm} C{3.75cm} C{3.75cm} C{3.75cm} } \toprule" if n == 1

replace all1_0  = "\multicolumn{8}{l}{\textbf{\textit{Panel a.} Main-Specification Construction.}}"   																									        if n == 2
replace all1_0  = "& \underline{Logit} & \underline{OLS} & \underline{Transformed} & \underline{Fixed Effects} & \underline{System GMM} & \underline{Additional Stock Lags} & \underline{Measurement Error}" 	if n == 3     

replace all0and = "   "       																			  if n == 2 | n == 3 | n == 12 | n == 13 | n == 14
replace all1and = "   "           						      							  				  if n == 2 | n == 3 | n == 12 | n == 13 | n == 14
replace all2and = "   "           						      							  				  if n == 2 | n == 3 | n == 12 | n == 13 | n == 14
replace all3and = "   "       															  				  if n == 2 | n == 3 | n == 12 | n == 13 | n == 14
replace all4and = "   "           						      							  				  if n == 2 | n == 3 | n == 12 | n == 13 | n == 14
replace all5and = "   "           						      							  				  if n == 2 | n == 3 | n == 12 | n == 13 | n == 14
replace all6and = "   "           						      							  				  if n == 2 | n == 3 | n == 12 | n == 13 | n == 14

replace all1_0 = "\multicolumn{1}{l}{Semi-Elastcity: $ \hat{\gamma}_{\Xi} $}"          if n == 4 | n == 15  
replace all1_0 = "\multicolumn{1}{l}{(s.e.)}"                                          if n == 5 | n == 16 

replace all1_0 = "\multicolumn{1}{l}{$ \hat{\gamma}_{n-1} $}"          if n == 8 | n == 19  
replace all1_0 = "\multicolumn{1}{l}{(s.e.)}"                          if n == 9 | n == 20 

replace all1_0 = "\multicolumn{1}{l}{Elasticity}"                      if n == 6  | n == 17  
replace all1_0 = "\multicolumn{1}{l}{(s.e.)}"                          if n == 7  | n == 18 

replace all1_0 = "\multicolumn{1}{l}{$ N $}"                           if n == 10 | n == 21  
replace all1_0 = "\multicolumn{1}{l}{Average $ A_i $ }"                if n == 11 | n == 22

replace all1_0  = "\multicolumn{8}{l}{\textbf{\textit{Panel b.} Robustness to Controls and Simultaneity of (Proportional) Prices and Income.}}" 												            if n == 12
replace all1_0  = "& \multicolumn{5}{c}{Flow of Children} & \multicolumn{2}{c}{Change in Labor Force Particiation}"                    										    					    if n == 13
replace all1_0  = "& \textit{Current} & \textit{+ 1-Year Lags} & \textit{+ 2-Year Lags} & \textit{Proportional Price} & \textit{Lump-Sum Price} & \textit{No Lagged Fertility} & \textit{Lagged Fertility}" if n == 14

order all1_0 all0and all1 all1and all2 all2and all3 all3and all4 all4and all5 all5and all6 all6and all7 all7and n
replace all7and = "\\" 
replace all7and = "\\ \bottomrule \end{tabular}"  if n == 22
replace all7and = " "                             if n == 1

// parenthesis for standard errors
foreach num of numlist 1(1)6 {
	replace all`num'and = ") & ("   if n == 5 | n == 7 | n == 9  | n == 16 | n == 18 | n == 20
}
replace all0and = "& ("    	        if n == 5 | n == 7 | n == 9  | n == 16 | n == 18 | n == 20
replace all5and = ") &"             if n == 20
replace all6and = "& ("             if n == 20

replace all5and = ") &"             if n == 18
replace all6and = "&"               if n == 18

replace all5and = "& N/A"            if n == 17
replace all6and = "& N/A"            if n == 17

replace all7and = ") \\ \\"         if n == 5 | n == 7 | n == 9  | n == 16 | n == 20
replace all7and = " \\ \\"          if n == 18
replace all7and = "\\ \midrule"     if n == 11
replace all7and = "\\ \cmidrule(l{.6cm}r{.4cm}){2-6} \cmidrule(l{.3cm}r{.3cm}){7-8}" if n == 13

// put together in string
gen all = " "
foreach num of numlist 1(1)7 {
	gen      all`num'b = all`num' if n == 10 | n == 21
	tostring all`num' , replace force format(%15.3fc)
	replace  all`num' = ""        if n == 10 | n == 21
	tostring all`num'b, replace force format(%15.0fc)
	replace  all`num'  = "" if all`num' == "."
	replace  all`num'b = "" if all`num'b == "."
}

global orderin all1_0 all0and
foreach num of numlist 1(1)7 {
	global orderin $orderin all`num' all`num'b all`num'and 
}
global orderin $orderin all`num'
order $orderin n

foreach var of varlist all1_0-all7and {
	replace  all = all + `var'
	replace  all`num' = "" if all`num' == "."
}

keep all
cd $output
outsheet using childrenfine_maindyn.tex, noquote nonames replace
