version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1200

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// base sample
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
gen basesample = e(sample)

// residualize variables from province times year times age
foreach var of varlist fine finealt_exp {
	reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}
foreach var of varlist children {
	reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
}

/////////////////////////////////////////////////////////////////
xtset simpleID age
// account for measurement error
xtdpd L(0/1).children_resid L(0).(fine_resid) if basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)
matrix   b1  = e(b)[1,2]
nlcom _b[l.children] - 1
matrix  b2   = r(b)[1,1]
xtdes if e(sample) == 1
matrix   N    = r(N)
matrix   T    = r(mean) 


// now run the bootstrap for system-gmm estimates
foreach b of numlist 1(1)$bootstraps {
	use data_interim_dyn.dta, clear
	drop segroup
	egen segroup       = group(province_code)
	keep simpleID segroup
	duplicates drop simpleID, force
	bsample, strata(segroup)
	drop segroup
	gen simpleIDalt = _n
	expand 166
	bysort simpleIDalt : egen age = seq()
	replace age = age - 63
	merge m:m simpleID age using data_interim_dyn
	keep if _merge == 3
	drop simpleID _merge
	rename simpleIDalt simpleID
	xtset simpleID age
	
	// base sample
	# delimit
	reghdfe  l.fine l.finealt_exp,
			 absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
	# delimit cr
	gen basesample = e(sample)

	// residualize variables from province times year times age
	foreach var of varlist fine finealt_exp {
		reghdfe l.`var' if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
	}
	foreach var of varlist children {
		reghdfe `var'   if basesample == 1, absorb(ageyeargroups) residual(`var'_resid)
	}
	
	// one lag
	xtdpd L(0/1).children_resid L(0).(fine_resid) if basesample == 1, dgmmiv(children_resid) dgmmiv(L2.(fine_resid), lag(1 .)) lgmmiv(children_resid L1.(fine_resid)) nocons twostep vce(robust) iv(finealt_exp_resid)
	matrix  b1_b`b'  = e(b)[1,2]
	nlcom _b[l.children] - 1
	matrix  b2_b`b'  = r(b)[1,1]
	matrix b_b`b' = [b1_b`b',b2_b`b']
	matrix colnames b_b`b' = b1_b`b' b2_b`b'
}

// organize first system and compute standard error
clear
foreach b of numlist 1(1)$bootstraps {
	svmat b_b`b', names(col)
}

foreach num of numlist 1(1)2 {
	egen b`num'_p90 = rowpctile(b`num'_b*), p(90)
	egen b`num'_p10 = rowpctile(b`num'_b*), p(10)
	
	foreach vary of varlist b`num'_b* {
		replace `vary' =. if `vary' < b`num'_p10 | `vary' > b`num'_p90 
	}
	egen   b`num'_se = rowsd(b`num'_b*)
	
	summ    b`num'_se
	matrix se`num' = r(mean)
}

// output matrix summarizing
matrix all = [b1,se1,b2,se2,N,T]'
mat list all
clear 
svmat all
cd $output
outsheet using childrenfine_maindyn_bootstrapstate.txt, noquote nonames replace
