version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1000

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global tfrdata   = "$storage/ChineseCensus" 
// output
global output    = "$projects/fduringcmorethanone_revision/output"

// cross-country fertility
cd $tfrdata
insheet using tfr_worldbank.csv, clear
rename v1 country 

sort country
# delimit
keep   if country == "China" 	    | country == "Japan"
        | country == "Korea, Rep."  	   
		| country == "OECD members" | country == "United States"
		| country == "South Asia"  
		| country == "Mongolia" | _n == 123
		| country == "India";
# delimit cr

// China, Japan, Mongolia, North Korea, South Korea

drop country
mkmat *, matrix(world)
matrix world = world'
clear 
svmat  world
rename world1 China
rename world2 India
rename world3 Japan
rename world4 NorthKorea
rename world5 SouthKorea 
rename world6 Mongolia
rename world7 OECD
rename world8 SouthAsia
rename world9 USA
gen year = _n + 1959

egen EastAsia = rowmean(NorthKorea SouthKorea Mongolia Japan)
keep if year >= 1970 & year <= 2015
egen    yearbin = cut(year) if year <= 2016, at(1960(2)2018)

collapse China EastAsia India OECD SouthAsia USA Japan, by(yearbin)
gen year = _n*2-1 + 1970
drop yearbin
tempfile world
save   "`world'", replace

cd $output
#delimit
twoway  (line    China    year, lcolor(gs0) xline(1979, lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(line    India    year, lcolor(gs4) yline(1, lcolor(gs14)))
		(line    Japan    year, lcolor(gs8))
		(line    USA      year, lcolor(gs12))
		
		(scatter India    year if year <= 2016,  msize(medium) msymbol(diamond)  mcolor(gs4))
		(scatter Japan    year if year <= 2016,  msize(medium) msymbol(triangle) mcolor(gs8))
		(scatter USA      year if year <= 2016,  msize(medium) msymbol(square)   mcolor(gs12)) 
		(scatter China    year if year <= 2016,  msize(medium) msymbol(circle)   mcolor(gs0))
		, 
		
		legend(label(8 "China") label(5 "India") label(6 "Japan") label(7 "United States") cols(4) order(8 5 6 7))
		  xlabel(1971[4]1991 1995[5]2015, angle(25) grid glcolor(gs14)) 
		  ylabel(1[1]6, angle(h) glcolor(gs14)) 
		  ytitle("Total Fertility Rate")
		  xtitle("Year")
		  graphregion(color(white)) plotregion(color(white));
#delimit cr
graph export tfr_crossection_chinaus.eps, replace

cd $output
#delimit
twoway  (line    EastAsia     year, lcolor(gs0) xline(1979, lwidth(vvthick) lpattern(solid) lcolor(gs14)))
		(line    SouthAsia    year, lcolor(gs6) yline(1, lcolor(gs14)))
		(line    OECD         year, lcolor(gs12))
		
		(scatter OECD        year if year <= 2016,  msize(medium) msymbol(square)   mcolor(gs12))
		(scatter SouthAsia   year if year <= 2016,  msize(medium) msymbol(dimaond)  mcolor(gs6))
		(scatter EastAsia    year if year <= 2016,  msize(medium) msymbol(triangle) mcolor(gs0)), 
		
		legend(label(6 "East Asia Excluding China") label(5 "South Asia") label(4 "OECD") cols(3) order(6 5 4))
		  xlabel(1971[4]1991 1995[5]2015, angle(25) grid glcolor(gs14)) 
		  ylabel(1[1]6, angle(h) glcolor(gs14)) 
		  ytitle("Total Fertility Rate")
		  xtitle("Year")
		  graphregion(color(white)) plotregion(color(white));
#delimit cr
graph export tfr_crossection_regions.eps, replace
