version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1000

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

// cadre promotion data 
cd $dataready
insheet  using charls_prefectures_withcodes.csv
tempfile prefecturecodes
save   "`prefecturecodes'", replace

// community data
cd $dataraw
cd 2011
use community, clear
duplicates tag communityID, gen(reps)
keep if reps == 0 
tempfile community
save   "`community'", replace

cd $dataready
use charls_females.dta, clear

// generate delta children outcomes
gen     lchildren = l.children
drop if lchildren ==.
gen dchildren = children - l.children

// merge community-level data
merge m:1 communityID using "`community'", keepusing(jh*)
keep if _merge != 2

// data groups
egen ageyeargroups = group(age year province_code)
egen segroup       = group(province_code birthyear)

// construct fine/permit variables
// construct fine/permit variables
gen    allowedaddchild2000 = allowedaddchild if year == 1999
bysort simpleID : egen allowedaddchild2005 = mean(allowedaddchild2000)
replace allowedaddchild = allowedaddchild2005 if year >= 2000 & allowedaddchild2005 !=.
replace fine = 0 if allowedaddchild == 0

xtset simpleID age
# delimit
reghdfe dchildren  l.fine
		  if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & lchildren != .,
		  absorb(i.simpleID i.ageyeargroups) cluster(segroup);
# delimit cr
keep if e(sample) == 1

// policy start
// measure (1) - community based 
bysort       simpleID : egen firstobserved = min(year)
bysort    communityID : egen policystart_1 = min(jh019)
replace policystart_1 = firstobserved if firstobserved > policystart_1 

// measure (2) - my documentation based 
sort simpleID age
gen     deltafine       = abs(fine - l.fine)
gen     policystart_2b   = year if deltafine > 0 & deltafine !=.  
replace policystart_2b   = year if fine      > 0 & fine !=. 
bysort       simpleID : egen policystart_2 = min(policystart_2b)

gen     finealt = 0         if jh026 == 2
replace finealt = 0         if jh026 == 1 & year <  jh026_1 
replace finealt = jh027     if jh026 == 1 & year >= jh026_1 & year !=.

replace finealt = jh029b_1_ if jh028 == 1 & year >= jh029a_1_ & year !=.
replace finealt = jh029b_2_ if jh028 == 1 & year >= jh029a_2_ & year !=.
replace finealt = jh029b_3_ if jh028 == 1 & year >= jh029a_3_ & year !=.

// with exemptions set by local leaders
gen     finealt_exp = finealt
replace finealt_exp = 0 if  jh020 == 2               &  firstchildgirl == 1 & selforspousehan == 1
replace finealt_exp = 0 if (jh020 == 3 | jh020 == 4) & selforspousehan == 1

// return to original fine in change in year of change and after  
replace finealt_exp = finealt if jh021 == 1 & year >= jh023 & year !=.

// put in exemptions
replace finealt_exp = 0 if  jh021 == 1 &  jh022 == 2               &  firstchildgirl == 1 & selforspousehan == 1 & year >= jh023 & year !=.
replace finealt_exp = 0 if  jh021 == 1 & (jh022 == 3 | jh022 == 4) & selforspousehan == 1 & year >= jh023 & year !=.

// live off from only one observation for minorities
replace finealt_exp = 0 if  jh025 == 2               &  firstchildgirl == 1 & selforspousehan == 0
replace finealt_exp = 0 if (jh025 == 3 | jh025 == 4) & selforspousehan == 0

summ    finealt_exp, d
replace finealt_exp =.  if finealt_exp > r(p95)
replace finealt_exp = 0 if allowedaddchild == 0

replace fine =.        if finealt_exp ==. | children ==.
replace finealt_exp =. if fine ==.        | children ==.

foreach var of varlist fine finealt_exp {
	summ    `var' if year == 1979
	replace `var' = `var'/r(mean)
	replace `var' = log(`var' + 1)
}

# delimit
reghdfe  dchildren l.fine l.finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
drop if e(sample) == 0

# delimit
reghdfe  l.fine        if year >= 1979 & year <= 2000 & age >= 15 & age <= 45,
	     absorb(i.simpleID i.ageyeargroups) resid(fine_resid1) vce(cluster segroup);
# delimit cr
replace fine_resid1 =. if e(sample) == 0

# delimit
reghdfe  l.finealt_exp if year >= 1979 & year <= 2000 & age >= 15 & age <= 45,
	     absorb(i.simpleID i.ageyeargroups) resid(fine_resid2) vce(cluster segroup);
# delimit cr
replace fine_resid2 =. if e(sample) == 0

// merge in prefectures codes
drop _merge
rename city prefecture_name
merge  m:m  prefecture_name province_name using "`prefecturecodes'"
keep if _merge == 3
drop _merge
drop segroup
egen segroup = group(prefectureid_1990 year)

// run base specification with non-missing prefecture id and then with fes
xtset simpleID age
# delimit
reghdfe     dchildren l.fine l.finealt_exp if age >= 15 & age <= 45 & year >= 1979 & year <= 2000 & prefectureid_1990 !=.,
            absorb(i.ID_ns i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1

// keep year in which mayor data are available 
keep if year >= 1985 & year <= 2000

// run base specification with non-missing prefecture id and relevant years
# delimit
reghdfe     d.children l.fine l.finealt_exp if age >= 15 & age <= 45 & year >= 1979 & year <= 2000 & prefectureid_1990 !=.,
            absorb(i.ID_ns i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1

// mere in information on cadres
merge m:1 prefectureid_1990 year using china_cadrepromotions
keep if _merge == 3
drop _merge

// run base speification with cadre subsample
xtset simpleID age
# delimit
reghdfe     dchildren l.fine l.finealt_exp if age >= 15 & age <= 45 & year >= 1979 & year <= 2000 & prefectureid_1990 !=.,
            absorb(i.ID_ns i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1
xtset ID_ns age

// define specifications
global spec4   l.fine l2.targetlesscensusfertility
global spec5   l.fine l2.targetlesscensusfertility   if urban_nbs  == 0
global spec6   l.fine l2.targetlesscensusfertility   if urban_nbs  == 1
global spec7   l.fine l2.targetlesscensusfertility   if accumumyearsinoffice <= 2.5
global spec8   l.fine l2.targetlesscensusfertility   if accumumyearsinoffice >  2.5
global spec9   l.fine l2.targetlesscensusfertility   if promoted == 0
global spec10  l.fine l2.targetlesscensusfertility   if promoted == 1

// standardize fine measures
foreach var of varlist targetlesscensusfertility {
	summ `var'                              
	replace `var' = (`var' - r(mean))/r(sd) 
}

matrix bse = J(1,2,.)
# delimit
reghdfe fine l.targetlesscensusfertility, 
			 vce(cluster segroup) absorb(i.ID_ns i.age i.year i.province_code); 
# delimit cr

// replace targetlessreportedfertility = abs(targetlessreportedfertility)
foreach num of numlist 10(1)4 {
	# delimit
	reghdfe ${spec`num'}, 
				 vce(cluster segroup) absorb(i.ID_ns i.age##i.year i.province_code); 
	# delimit cr
	matrix b`num' = e(b)
	matrix V`num' = e(V)
	matrix bse = [bse \ [b`num'[1,1],sqrt(V`num'[1,1])] ]
}
matrix bse = bse[2...,1...]
matrix colnames bse = b se

// plots: target less realized
clear
svmat bse, names(col)
gen max = b + 1.96*se
gen min = b - 1.96*se
gen     spec = _n 
drop if spec < 3

cd $output
#delimit
twoway  	(rcap    max min spec, lcolor(gs0) horizontal)
		    (scatter spec       b, mcolor(gs0) msymbol(circle) xline(0,  lwidth(vvthick) lpattern(solid) lcolor(gs14))), 
		     
			 legend(label(2 "Estimate")  label(1 "95% C.I.") rows(1) order(2 1) /*position(2) ring(0)*/ size(small))
		  
		      xlabel(-.15[.05]0, labsize(small) grid glcolor(gs14) angle(h)) 
		      ylabel(7 "Full Sample" 6 "Rural Areas" 5 "Urban Areas" 4 `" "Inexperienced" "Mayor" "' 3 `" "Experienced" "Mayor" "', 
			         labsize(small) angle(h) glcolor(gs14)) 
		     
			 xtitle("Regression Coefficient:" 
		            "Residual {it:log} (Price) on Mayor Performace Measure", size(small))
		     ytitle("")
		  graphregion(color(white)) plotregion(color(white));
#delimit cr
graph export fine_mayorcorroboration.eps, replace
