version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1000

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

cd $dataready
use data_interim_dyn, clear

// base sample
# delimit
reghdfe  l.fine l.finealt_exp,
	     absorb(i.simpleID i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1

# delimit
reghdfe  lfine,
	     absorb(i.ageyeargroups) resid(fine_resid1) vce(cluster segroup);
# delimit cr
replace fine_resid1 =. if e(sample) == 0

# delimit
reghdfe  lfinealt_exp,
	     absorb(i.ageyeargroups) resid(fine_resid2) vce(cluster segroup);
# delimit cr
replace fine_resid2 =. if e(sample) == 0

// regressions details
# delimit
reghdfe  lfine lfinealt_exp if fine_resid1 !=. & fine_resid2 !=.,
	     absorb(i.ageyeargroups) vce(cluster segroup);
# delimit cr
keep if e(sample) == 1
matrix b    = e(b)[1,1]
matrix se   = sqrt(e(V)[1,1])
matrix F    = e(F)
matrix R2a  = e(r2)
xtdes 
matrix N    = r(N)
matrix T    = r(mean) 

# delimit
reghdfe  lfine if fine_resid1 !=. & fine_resid2 !=.,
	     absorb(i.ageyeargroups) vce(cluster segroup);
# delimit cr
matrix R2b  = e(r2)

// bins reg
cd $output
binsreg fine_resid1 fine_resid2, savedata(binnedfines) replace

// fine histograms
preserve
collapse (sd) fine_resid1 fine_resid2, by(simpleID)

foreach var of varlist fine_resid1 fine_resid2 {
	summ `var'
	local w`var' = r(mean)
	local w`var' = string(`w`var'',"%9.2f")
}
restore

foreach var of varlist fine_resid1 fine_resid2 {
	summ `var'
	local `var'se = r(sd) 
	local `var'se = string(``var'se',"%9.2f")
}

# delimit
global box1  text(.3 -0.575
	 "Standard Deviation"
	 "Baseline Documentation"
	 " "
	 "Across Individuals and Time"
	 "`fine_resid1se'"
	 " "
	 "Within-Individual (Average)"
	 "`wfine_resid1'"
         , place(c) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

# delimit
global box2  text(.3 0.575
	 "Standard Deviation"
	 "Surveys with Leaders"
	 " "
	 "Across Individuals and Time"
	 "`fine_resid2se'"
	 " "
	 "Within-Individual (Average)"
	 "`wfine_resid2'"
         , place(c) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

#delimit
twoway (hist     fine_resid1 if fine_resid1 >=-1 & fine_resid1 <= 1, fraction color(gs10) barwidth(.04) bin(20))
	   (hist     fine_resid2 if fine_resid2 >=-1 & fine_resid2 <= 1, fraction fcolor(none) lcolor(gs0) barwidth(.04) bin(20)),	  
		  

		legend(label(1 "Baseline Documentation")
			   label(2 "Surveys with Officials") rows(1) order(1 2))
		  xlabel(-1[.5]1, grid glcolor(gs14)) 
		  ylabel(, angle(h) glcolor(gs14)) 
		  ytitle("Fraction")
		  xtitle("Residual {it:ln} (Price)")
		  graphregion(color(white)) plotregion(color(white))
		  $box1 $box2;
#delimit cr
graph export fine_variation.eps, replace

// now show bin scatter
use binnedfines, clear

// labels for individual regression
foreach var in b se {
	local `var' = `var'[1,1]
	local `var' = string(``var'',"%15.3f")
}

foreach var in F R2a R2b T {
	local `var' = `var'[1,1]
	local `var' = string(``var'',"%9.2f")
}

foreach var in T {
	local `var' = `var'[1,1]
	local `var' = string(``var'',"%9.1f")
}

foreach var in N {
	local `var' = `var'[1,1]
	local `var' = string(``var'',"%15.0fc")
}

# delimit
global box3  text(-.15 1.5
	 "Slope: `b'"
	 "(s.e.`se')"
	 " "
	 "R{sup:2} Allowing Slope {&ne} 0: `R2a'"
	 " "
	 "R{sup:2} Imposing Slope = 0: `R2b'"
	 " "
	 "Individuals: `N'"
	 "Average Individual Observations: `T'"
         , size(small) place(c) box just(c) margin(l+1 b+1 t+1 r+1) fcolor(none)); 
# delimit cr

// drop two outliers 
drop if dots_x > 3
#delimit 
twoway  (lfit     dots_fit dots_x, lcolor(gs0) lwidth(thick)) 	
		(scatter  dots_fit dots_x, mfcolor(white) mlcolor(gs0) msize(large) msymbol(circle))				
	   
	,
		 legend(label(1 "Full-Sample Linear Fit")
			    label(2 "Scattered Bins") rows(1) order(2 1))
		  
		  ylabel(-.3[.15].3, grid glcolor(gs14)        angle(h)) 
		  xlabel(, grid glcolor(gs14) angle(h)) 
		  ytitle("Residual {it:ln} (Price): Baseline Documentation")
		  xtitle("Residual {it:ln} (Price): Surveys with Officials")
		  graphregion(color(white)) plotregion(fcolor(white))
		  ${box3};
#delimit cr
graph export fine_bins.eps, replace
erase binnedfines.dta
