version 17.0
set more off
clear all
set matsize 11000
set maxvar  32000
set seed 0
global bootstraps 1000

// set environment variables
global projects: env projects
global storage : env storage

// set general locations
// raw data
global dataraw   = "$storage/charls/dataraw"
// ready data
global dataready = "$storage/charls/dataready"
// output
global output    = "$projects/fduringcmorethanone_revision/output"

// community data
cd $dataraw
cd 2011
use community, clear
duplicates tag communityID, gen(reps)
keep if reps == 0 
tempfile community
save   "`community'", replace

// point estimates
cd $dataready
use charls_females.dta, clear

// generate delta children outcomes
gen dchildren = children - l.children

// merge community-level data
merge m:1 communityID using "`community'", keepusing(jh*)
keep if _merge != 2

// data groups
egen ageyeargroups = group(age year province_code)
egen segroup       = group(province_code birthyear)

// construct fine/permit variables
gen    allowedaddchild2000 = allowedaddchild if year == 1999
bysort simpleID : egen allowedaddchild2005 = mean(allowedaddchild2000)
replace allowedaddchild = allowedaddchild2005 if year >= 2000 & allowedaddchild2005 !=.
replace fine = 0 if allowedaddchild == 0

xtset simpleID age
# delimit
reghdfe dchildren  l.fine
		  if year >= 1979 & year <= 2000 & age >= 15 & age <= 45 & l.children != .,
		  absorb(i.simpleID i.ageyeargroups) cluster(segroup);
# delimit cr
keep if e(sample) == 1

// lump all regions
gen econregion = 1

gen exe1 = exemption5    													   // ethnicity
gen exe2 = exemption16   													   // sex of the first child
egen    exe3 = rowtotal(exemption1 exemption2 exemption3 exemption17), missing // 1st child alive or older
replace exe3 = 1 if exe3 >= 1 & exe3 !=.
egen    exe4 = rowtotal(exemption6 exemption7 exemption9 exemption15), missing // job difficulty
replace exe4 = 1 if exe4 >= 1 & exe4 !=.
egen    exe5 = rowtotal(exemption10 exemption11 exemption13), missing          // male scarcity
replace exe5 = 1 if exe5 >= 1 & exe5 !=.

matrix all = J(1,5,.)
matrix colnames all = value exemption ind year region
foreach num in 1 2 3 4 5 {
	foreach numy in 1 {
		foreach year of numlist 1979[1]2000 {
				foreach ex in 0 1 {
					summ fine if exe`num' == `ex' & econregion == `numy' & year == `year'
					matrix cfine_e`num'_`ex'_ecreg`numy'_year`year' = [r(mean),`num',`ex',`year',`numy']
					matrix colnames cfine_e`num'_`ex'_ecreg`numy'_year`year' = value exemption ind year region
					mat_rapp all : all cfine_e`num'_`ex'_ecreg`numy'_year`year'
			}	
		}
	}
}

clear
svmat all, names(col)
drop if value == .
sort region exemption ind year 
   
cd $output
foreach num of numlist 1 {
	#delimit
	twoway  (scatter value year if exemption == 1 & ind == 0 & region == `num', msymbol(circle) mfcolor(white) mlcolor(gs3))
			(line value year    if exemption == 1 & ind == 0 & region == `num', lcolor(gs3)    yline(2  , lpattern(solid) lcolor(gs14)))
			(scatter value year if exemption == 1 & ind == 1 & region == `num', msymbol(circle) mcolor(gs3))
			(line value year    if exemption == 1 & ind == 1 & region == `num', lcolor(gs3))
			(scatter value year if exemption == 2 & ind == 0 & region == `num', msymbol(square) mfcolor(white) mlcolor(gs6))
			(line value year    if exemption == 2 & ind == 0 & region == `num', lcolor(gs6))
			(scatter value year if exemption == 2 & ind == 1 & region == `num', msymbol(square) mcolor(gs6))	
			(line value year    if exemption == 2 & ind == 1 & region == `num', lcolor(gs6))	

		, 
			legend(label(1 "Han (Majority)")
			       label(3 "Non-Han (Minority)") label(5 "First Child Boy") label(7 "First Child Girl") row(2) order(1 3 5 7))
			  xlabel(1979 1985[5]2000, angle(25) grid glcolor(gs14))
			  ylabel(0[.5]2,  angle(h) glcolor(gs14))
			  xtitle("Year") 
			  ytitle("Average Price"
			  "(Years of Household Labor Income)")
			  graphregion(color(white)) plotregion(fcolor(white));
	#delimit cr
	graph export fine_mags_all_reduceseries_`num'.eps, replace
	
	
	#delimit
	twoway  (scatter value year if exemption == 4 & ind == 0 & region == `num', msymbol(circle) mfcolor(white) mlcolor(gs3))
			(line value year    if exemption == 4 & ind == 0 & region == `num', lcolor(gs3)    yline(2  , lpattern(solid) lcolor(gs14)))
			(scatter value year if exemption == 4 & ind == 1 & region == `num', msymbol(circle) mcolor(gs3))
			(line value year    if exemption == 4 & ind == 1 & region == `num', lcolor(gs3))
			(scatter value year if exemption == 5 & ind == 0 & region == `num', msymbol(square) mfcolor(white) mlcolor(gs6))
			(line value year    if exemption == 5 & ind == 0 & region == `num', lcolor(gs6))
			(scatter value year if exemption == 5 & ind == 1 & region == `num', msymbol(square) mcolor(gs6))	
			(line value year    if exemption == 5 & ind == 1 & region == `num', lcolor(gs6))	

		, 
			legend(label(1 "Job Difficulty-No")
			       label(3 "Job Difficulty-Yes") label(5 "Male Scarcity-No") label(7 "Male Scarcity-Yes") row(2) order(1 3 5 7))
			  xlabel(1979 1985[5]2000, angle(25) grid glcolor(gs14))
			  ylabel(0[.5]2, angle(h) glcolor(gs14))
			  xtitle("Year") 
			  ytitle("Average Price"
			  "(Years of Household Labor Income)")
			  graphregion(color(white)) plotregion(fcolor(white));
	#delimit cr
	graph export fine_mags_all_reduceseriesb_`num'.eps, replace
	
}
